@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2005-2023 The Octave Project Developers
+// Copyright (C) 2005-2026 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -83,7 +83,7 @@ if @var{S} is m-by-n, rows with more than
 columns with more than
 @code{max (16, @var{knobs}(3) * sqrt (min (@var{m}, @var{n})))} entries are
 ignored and ordered last in the output permutation
-(subject to the cmember constraints).
+(subject to the @var{cmember} constraints).
 
 @item @var{knobs}(4)
 if nonzero, aggressive absorption is performed.
@@ -277,7 +277,7 @@ csymamd, amd, colamd, symamd, and other related orderings.
       OCTAVE_LOCAL_BUFFER (suitesparse_integer, cmember, cslen);
       for (octave_idx_type i = 0; i < cslen; i++)
         // convert cmember from 1-based to 0-based
-        cmember[i] = static_cast<suitesparse_integer>(in_cmember(i) - 1);
+        cmember[i] = static_cast<suitesparse_integer> (in_cmember(i) - 1);
 
       if (cslen != n_col)
         error ("ccolamd: CMEMBER must be of length equal to #cols of A");
