@@ -82,34 +82,32 @@
 #line 26 "../libinterp/corefcn/oct-tex-parser.yy"
 
 
-#define YYDEBUG 1
+// #define OCTAVE_TEX_DEBUG 1
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
 #endif
 
 #include "text-engine.h"
-
 // oct-tex-parser.h must be included after text-engine.h
 #include "oct-tex-parser.h"
 
 extern int octave_tex_lex (YYSTYPE *, void *);
- static void yyerror (octave::text_parser_tex& parser, const char *s);
+static void yyerror (octave::text_parser_tex& parser, const char *s);
 
 #define m_scanner parser.get_scanner ()
 #define yyalloc octave_tex_yyalloc
 
 #if defined (HAVE_PRAGMA_GCC_DIAGNOSTIC)
-   // Disable this warning for code that is generated by Bison,
-   // including grammar rules.  Push the current state so we can
-   // restore the warning state prior to functions we define at
-   // the bottom of the file.
+   // Disable this warning for code that is generated by Bison, including
+   // grammar rules.  Push the current state so we can restore the warning
+   // state prior to functions we define at the bottom of the file.
 #  pragma GCC diagnostic push
 #  pragma GCC diagnostic ignored "-Wold-style-cast"
 #endif
 
 
-#line 113 "libinterp/corefcn/oct-tex-parser.cc"
+#line 111 "libinterp/corefcn/oct-tex-parser.cc"
 
 # ifndef YY_CAST
 #  ifdef __cplusplus
@@ -534,10 +532,10 @@ static const yytype_int8 yytranslate[] =
 /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,   109,   109,   111,   115,   119,   121,   123,   125,   129,
-     133,   140,   145,   151,   156,   158,   159,   160,   161,   162,
-     163,   164,   165,   168,   170,   172,   176,   178,   180,   184,
-     186,   190,   192,   197,   199,   204,   205
+       0,   107,   107,   109,   113,   117,   119,   121,   123,   127,
+     131,   138,   143,   149,   154,   156,   157,   158,   159,   160,
+     161,   162,   163,   166,   168,   170,   174,   176,   178,   182,
+     184,   188,   190,   195,   197,   202,   203
 };
 #endif
 
@@ -909,93 +907,93 @@ yydestruct (const char *yymsg,
   switch (yykind)
     {
     case YYSYMBOL_CH: /* CH  */
-#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 94 "../libinterp/corefcn/oct-tex-parser.yy"
             { }
-#line 915 "libinterp/corefcn/oct-tex-parser.cc"
+#line 913 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_NUM: /* NUM  */
-#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 94 "../libinterp/corefcn/oct-tex-parser.yy"
             { }
-#line 921 "libinterp/corefcn/oct-tex-parser.cc"
+#line 919 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_SYM: /* SYM  */
-#line 96 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 94 "../libinterp/corefcn/oct-tex-parser.yy"
             { }
-#line 927 "libinterp/corefcn/oct-tex-parser.cc"
+#line 925 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_simple_string: /* simple_string  */
-#line 97 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 95 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).str); }
-#line 933 "libinterp/corefcn/oct-tex-parser.cc"
+#line 931 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_symbol_element: /* symbol_element  */
-#line 97 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 95 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 939 "libinterp/corefcn/oct-tex-parser.cc"
+#line 937 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_font_modifier_element: /* font_modifier_element  */
-#line 97 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 95 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 945 "libinterp/corefcn/oct-tex-parser.cc"
+#line 943 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_fontsize_element: /* fontsize_element  */
-#line 97 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 95 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 951 "libinterp/corefcn/oct-tex-parser.cc"
+#line 949 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_fontname_element: /* fontname_element  */
-#line 97 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 95 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 957 "libinterp/corefcn/oct-tex-parser.cc"
+#line 955 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_color_element: /* color_element  */
-#line 97 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 95 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 963 "libinterp/corefcn/oct-tex-parser.cc"
+#line 961 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_string_element: /* string_element  */
-#line 97 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 95 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 969 "libinterp/corefcn/oct-tex-parser.cc"
+#line 967 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_superscript_element: /* superscript_element  */
-#line 97 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 95 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 975 "libinterp/corefcn/oct-tex-parser.cc"
+#line 973 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_subscript_element: /* subscript_element  */
-#line 97 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 95 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 981 "libinterp/corefcn/oct-tex-parser.cc"
+#line 979 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_combined_script_element: /* combined_script_element  */
-#line 97 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 95 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_base); }
-#line 987 "libinterp/corefcn/oct-tex-parser.cc"
+#line 985 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_string_element_list: /* string_element_list  */
-#line 97 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 95 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_list); }
-#line 993 "libinterp/corefcn/oct-tex-parser.cc"
+#line 991 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
     case YYSYMBOL_scoped_string_element_list: /* scoped_string_element_list  */
-#line 97 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 95 "../libinterp/corefcn/oct-tex-parser.yy"
             { delete ((*yyvaluep).e_list); }
-#line 999 "libinterp/corefcn/oct-tex-parser.cc"
+#line 997 "libinterp/corefcn/oct-tex-parser.cc"
         break;
 
       default:
@@ -1357,180 +1355,180 @@ yyreduce:
   switch (yyn)
     {
   case 2: /* simple_string: CH  */
-#line 110 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 108 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.str) = new std::string (1, (yyvsp[0].ch)); }
-#line 1363 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1361 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 3: /* simple_string: simple_string CH  */
-#line 112 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 110 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyvsp[-1].str)->append (1, (yyvsp[0].ch)); (yyval.str) = (yyvsp[-1].str); }
-#line 1369 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1367 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 4: /* symbol_element: SYM  */
-#line 116 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 114 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_symbol ((yyvsp[0].sym)); }
-#line 1375 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1373 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 5: /* font_modifier_element: BF  */
-#line 120 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 118 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_fontstyle (octave::text_element_fontstyle::bold); }
-#line 1381 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1379 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 6: /* font_modifier_element: IT  */
-#line 122 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 120 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_fontstyle (octave::text_element_fontstyle::italic); }
-#line 1387 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1385 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 7: /* font_modifier_element: SL  */
-#line 124 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 122 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_fontstyle (octave::text_element_fontstyle::oblique); }
-#line 1393 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1391 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 8: /* font_modifier_element: RM  */
-#line 126 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 124 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_fontstyle (octave::text_element_fontstyle::normal); }
-#line 1399 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1397 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 9: /* fontsize_element: FONTSIZE START NUM END  */
-#line 130 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 128 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_fontsize ((yyvsp[-1].num)); }
-#line 1405 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1403 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 10: /* fontname_element: FONTNAME START simple_string END  */
-#line 134 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 132 "../libinterp/corefcn/oct-tex-parser.yy"
                           {
                             (yyval.e_base) = new octave::text_element_fontname (*(yyvsp[-1].str));
                             delete (yyvsp[-1].str);
                           }
-#line 1414 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1412 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 11: /* color_element: COLOR START simple_string END  */
-#line 141 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 139 "../libinterp/corefcn/oct-tex-parser.yy"
                           {
                             (yyval.e_base) = new octave::text_element_color (*(yyvsp[-1].str));
                             delete (yyvsp[-1].str);
                           }
-#line 1423 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1421 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 12: /* color_element: COLOR_RGB START NUM NUM NUM END  */
-#line 146 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 144 "../libinterp/corefcn/oct-tex-parser.yy"
                           {
                             (yyval.e_base) = new octave::text_element_color ((yyvsp[-3].num), (yyvsp[-2].num), (yyvsp[-1].num));
                           }
-#line 1431 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1429 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 13: /* string_element: simple_string  */
-#line 152 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 150 "../libinterp/corefcn/oct-tex-parser.yy"
                           {
                             (yyval.e_base) = new octave::text_element_string (*(yyvsp[0].str));
                             delete (yyvsp[0].str);
                           }
-#line 1440 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1438 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 14: /* string_element: scoped_string_element_list  */
-#line 157 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 155 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = (yyvsp[0].e_list); }
-#line 1446 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1444 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 23: /* superscript_element: SUPER CH  */
-#line 169 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 167 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_superscript ((yyvsp[0].ch)); }
-#line 1452 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1450 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 24: /* superscript_element: SUPER scoped_string_element_list  */
-#line 171 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 169 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_superscript ((yyvsp[0].e_list)); }
-#line 1458 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1456 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 25: /* superscript_element: SUPER symbol_element  */
-#line 173 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 171 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_superscript ((yyvsp[0].e_base)); }
-#line 1464 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1462 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 26: /* subscript_element: SUB CH  */
-#line 177 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 175 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_subscript ((yyvsp[0].ch)); }
-#line 1470 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1468 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 27: /* subscript_element: SUB scoped_string_element_list  */
-#line 179 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 177 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_subscript ((yyvsp[0].e_list)); }
-#line 1476 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1474 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 28: /* subscript_element: SUB symbol_element  */
-#line 181 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 179 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_subscript ((yyvsp[0].e_base)); }
-#line 1482 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1480 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 29: /* combined_script_element: subscript_element superscript_element  */
-#line 185 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 183 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_combined ((yyvsp[-1].e_base), (yyvsp[0].e_base)); }
-#line 1488 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1486 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 30: /* combined_script_element: superscript_element subscript_element  */
-#line 187 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 185 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_base) = new octave::text_element_combined ((yyvsp[-1].e_base), (yyvsp[0].e_base)); }
-#line 1494 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1492 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 31: /* string_element_list: string_element  */
-#line 191 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 189 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_list) = new octave::text_element_list ((yyvsp[0].e_base)); }
-#line 1500 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1498 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 32: /* string_element_list: string_element_list string_element  */
-#line 193 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 191 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyvsp[-1].e_list)->push_back ((yyvsp[0].e_base)); (yyval.e_list) = (yyvsp[-1].e_list); }
-#line 1506 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1504 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 33: /* scoped_string_element_list: START string_element_list END  */
-#line 198 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 196 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_list) = (yyvsp[-1].e_list); }
-#line 1512 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1510 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 34: /* scoped_string_element_list: START END  */
-#line 200 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 198 "../libinterp/corefcn/oct-tex-parser.yy"
                           { (yyval.e_list) = new octave::text_element_list (); }
-#line 1518 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1516 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 35: /* string: %empty  */
-#line 204 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 202 "../libinterp/corefcn/oct-tex-parser.yy"
                           { parser.set_parse_result (new octave::text_element_string ("")); }
-#line 1524 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1522 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
   case 36: /* string: string_element_list  */
-#line 206 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 204 "../libinterp/corefcn/oct-tex-parser.yy"
                           { parser.set_parse_result ((yyvsp[0].e_list)); }
-#line 1530 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1528 "libinterp/corefcn/oct-tex-parser.cc"
     break;
 
 
-#line 1534 "libinterp/corefcn/oct-tex-parser.cc"
+#line 1532 "libinterp/corefcn/oct-tex-parser.cc"
 
       default: break;
     }
@@ -1736,31 +1734,33 @@ yypushreturn:
 #undef yyvs
 #undef yyvsp
 #undef yystacksize
-#line 209 "../libinterp/corefcn/oct-tex-parser.yy"
+#line 207 "../libinterp/corefcn/oct-tex-parser.yy"
 
 
 #if defined (HAVE_PRAGMA_GCC_DIAGNOSTIC)
-   // Restore prevailing warning state for remainder of the file.
-#  pragma GCC diagnostic pop
+  // Restore prevailing warning state for remainder of the file.
+  #pragma GCC diagnostic pop
 #endif
 
 OCTAVE_BEGIN_NAMESPACE(octave)
 
-  text_element*
-  text_parser_tex::parse (const std::string& s)
-  {
-    octave_tex_debug = 0;
+text_element *
+text_parser_tex::parse (const std::string& s)
+{
+#if OCTAVE_TEX_DEBUG
+  octave_tex_debug = 1;
+#endif
 
-    if (init_lexer (s))
-      {
-        m_result = nullptr;
+  if (init_lexer (s))
+    {
+      m_result = nullptr;
 
-        if (octave_tex_parse (*this) == 0)
-          return m_result;
-      }
+      if (octave_tex_parse (*this) == 0)
+        return m_result;
+    }
 
-    return new text_element_string (s);
-  }
+  return new text_element_string (s);
+}
 
 OCTAVE_END_NAMESPACE(octave)
 
