@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2012-2025 The Octave Project Developers
+// Copyright (C) 2012-2026 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -54,9 +54,8 @@
 #include "pt-walk.h"
 #include "unwind-prot.h"
 
-// Define to 1 to enable debugging statements.
-#define DEBUG_TRACE 0
-#if DEBUG_TRACE
+#define OCTAVE_CDEF_CLASS_DEBUG 0
+#if OCTAVE_CDEF_CLASS_DEBUG
 #  include <iostream>
 #endif
 
@@ -112,6 +111,8 @@ cdef_class::cdef_class_rep::find_method (const std::string& nm, bool local)
       // Look into superclasses
 
       Cell super_classes = get ("SuperClasses").cell_value ();
+      cdef_class cls1;
+      int nfnd = 0;
 
       for (int i = 0; i < super_classes.numel (); i++)
         {
@@ -120,8 +121,22 @@ cdef_class::cdef_class_rep::find_method (const std::string& nm, bool local)
           cdef_method meth = cls.find_method (nm);
 
           if (meth.ok ())
-            return meth;
+            {
+              nfnd++;
+              if (nfnd == 1)
+                cls1 = cls;
+              else if (nfnd == 2)
+                // FIXME: This error is emitted when a method with conflicting
+                //        definitions is attempted to be used. Ideally, this
+                //        error would be emitted on construction of the object.
+                error ("method %s: conflicting definitions in classes '%s' and '%s'",
+                       nm.c_str (), cls1.get_name ().c_str (),
+                       cls.get_name ().c_str ());
+            }
         }
+
+      if (nfnd == 1)
+        return cls1.find_method (nm);
     }
 
   return cdef_method ();
@@ -229,7 +244,19 @@ private:
 void
 cdef_class::cdef_class_rep::install_method (const cdef_method& meth)
 {
-  m_method_map[meth.get_name ()] = meth;
+  std::string method_name = meth.get_name ();
+  auto it = m_method_map.find (method_name);
+  //  Check if a method with the same name already exists before
+  //  installing a new one.
+  if (it != m_method_map.end ())
+    {
+      std::string class_file = file_name ();
+      error ("duplicate method '%s' in class '%s' in file '%s'",
+             method_name.c_str (), get_name ().c_str (), class_file.c_str ());
+    }
+
+  // Now safely install the new method
+  m_method_map[method_name] = meth;
 
   m_member_count++;
 
@@ -263,7 +290,7 @@ cdef_class::cdef_class_rep::install_method (const cdef_method& meth)
 
               for (const auto& cdef_cls : explicit_ctor_list)
                 {
-#if DEBUG_TRACE
+#if OCTAVE_CDEF_CLASS_DEBUG
                   std::cerr << "explicit superclass constructor: "
                             << cdef_cls.get_name () << std::endl;
 #endif
@@ -367,6 +394,8 @@ cdef_class::cdef_class_rep::find_property (const std::string& nm)
   // Look into superclasses
 
   Cell super_classes = get ("SuperClasses").cell_value ();
+  cdef_class cls1;
+  int nfnd = 0;
 
   for (int i = 0; i < super_classes.numel (); i++)
     {
@@ -375,8 +404,22 @@ cdef_class::cdef_class_rep::find_property (const std::string& nm)
       cdef_property prop = cls.find_property (nm);
 
       if (prop.ok ())
-        return prop;
-    }
+        {
+          nfnd++;
+          if (nfnd == 1)
+            cls1 = cls;
+          else if (nfnd == 2)
+            // FIXME: This error is emitted when a property with conflicting
+            //        definitions is attempted to be used. Ideally, this
+            //        error would be emitted on construction of the object.
+            error ("property %s: conflicting definitions in classes '%s' and '%s'",
+                   nm.c_str (), cls1.get_name ().c_str (),
+                   cls.get_name ().c_str ());
+        }
+     }
+
+  if (nfnd == 1)
+    return cls1.find_property (nm);
 
   return cdef_property ();
 }
@@ -384,7 +427,19 @@ cdef_class::cdef_class_rep::find_property (const std::string& nm)
 void
 cdef_class::cdef_class_rep::install_property (const cdef_property& prop)
 {
-  m_property_map[prop.get_name ()] = prop;
+  std::string prop_name = prop.get_name ();
+  auto it = m_property_map.find (prop_name);
+  //  Check if a property with the same name already exists before
+  //  installing a new one.
+  if (it != m_property_map.end ())
+    {
+      std::string class_file = file_name ();
+      error ("duplicate property '%s' in class '%s' in file '%s'",
+             prop_name.c_str (), get_name ().c_str (), class_file.c_str ());
+    }
+
+  m_property_map[prop_name] = prop;
+
   // Register the insertion rank of this property
   m_property_rank_map[prop.get_name ()] = m_member_count;
 
@@ -586,7 +641,7 @@ cdef_class::cdef_class_rep::meta_subsref (const std::string& type,
     case '(':
       // Constructor call
 
-#if DEBUG_TRACE
+#if OCTAVE_CDEF_CLASS_DEBUG
       std::cerr << "constructor" << std::endl;
 #endif
 
@@ -597,7 +652,7 @@ cdef_class::cdef_class_rep::meta_subsref (const std::string& type,
       {
         // Static method, constant (or property?)
 
-#if DEBUG_TRACE
+#if OCTAVE_CDEF_CLASS_DEBUG
         std::cerr << "static method/property" << std::endl;
 #endif
 
@@ -818,9 +873,10 @@ cdef_class::cdef_class_rep::get_method (int line) const
 }
 
 octave_value
-cdef_class::cdef_class_rep::construct (const octave_value_list& args)
+cdef_class::cdef_class_rep::construct (const octave_value_list& args,
+                                       const bool default_initialize)
 {
-  cdef_object obj = construct_object (args);
+  cdef_object obj = construct_object (args, default_initialize);
 
   if (obj.ok ())
     return to_ov (obj);
@@ -829,7 +885,8 @@ cdef_class::cdef_class_rep::construct (const octave_value_list& args)
 }
 
 cdef_object
-cdef_class::cdef_class_rep::construct_object (const octave_value_list& args)
+cdef_class::cdef_class_rep::construct_object (const octave_value_list& args,
+                                              const bool default_initialize)
 {
   if (is_abstract ())
     error ("cannot instantiate object for abstract class '%s'",
@@ -897,7 +954,8 @@ cdef_class::cdef_class_rep::construct_object (const octave_value_list& args)
 
       initialize_object (obj);
 
-      run_constructor (obj, args);
+      if (! default_initialize)
+        run_constructor (obj, args);
 
       return obj;
     }
@@ -956,7 +1014,7 @@ cdef_class::make_meta_class (interpreter& interp,
   if (! t->package_name ().empty ())
     full_class_name = t->package_name () + '.' + full_class_name;
 
-#if DEBUG_TRACE
+#if OCTAVE_CDEF_CLASS_DEBUG
   std::cerr << "class: " << full_class_name << std::endl;
 #endif
 
@@ -978,7 +1036,7 @@ cdef_class::make_meta_class (interpreter& interp,
         {
           std::string sclass_name = (scls)->class_name ();
 
-#if DEBUG_TRACE
+#if OCTAVE_CDEF_CLASS_DEBUG
           std::cerr << "superclass: " << sclass_name << std::endl;
 #endif
 
@@ -1023,7 +1081,7 @@ cdef_class::make_meta_class (interpreter& interp,
           std::string aname = attr->ident ()->name ();
           octave_value avalue = compute_attribute_value (tw, attr);
 
-#if DEBUG_TRACE
+#if OCTAVE_CDEF_CLASS_DEBUG
           std::cerr << "class attribute: " << aname << " = "
                     << attribute_value_to_string (attr, avalue) << std::endl;
 #endif
@@ -1052,7 +1110,7 @@ cdef_class::make_meta_class (interpreter& interp,
         {
           std::map<std::string, octave_value> amap;
 
-#if DEBUG_TRACE
+#if OCTAVE_CDEF_CLASS_DEBUG
           std::cerr << "method block" << std::endl;
 #endif
 
@@ -1065,7 +1123,7 @@ cdef_class::make_meta_class (interpreter& interp,
                   std::string aname = attr_p->ident ()->name ();
                   octave_value avalue = compute_attribute_value (tw, attr_p);
 
-#if DEBUG_TRACE
+#if OCTAVE_CDEF_CLASS_DEBUG
                   std::cerr << "method attribute: " << aname << " = "
                             << attribute_value_to_string (attr_p, avalue)
                             << std::endl;
@@ -1094,9 +1152,9 @@ cdef_class::make_meta_class (interpreter& interp,
                     {
                       cdef_method meth = cdm.make_method (retval, mname, mtd);
 
-#if DEBUG_TRACE
+#if OCTAVE_CDEF_CLASS_DEBUG
                       std::cerr << (mname == class_name ? "constructor"
-                                    : "method")
+                                                        : "method")
                                 << ": " << mname << std::endl;
 #endif
 
@@ -1164,7 +1222,7 @@ cdef_class::make_meta_class (interpreter& interp,
         {
           std::map<std::string, octave_value> amap;
 
-#if DEBUG_TRACE
+#if OCTAVE_CDEF_CLASS_DEBUG
           std::cerr << "property block" << std::endl;
 #endif
 
@@ -1177,7 +1235,7 @@ cdef_class::make_meta_class (interpreter& interp,
                   std::string aname = attr_p->ident ()->name ();
                   octave_value avalue = compute_attribute_value (tw, attr_p);
 
-#if DEBUG_TRACE
+#if OCTAVE_CDEF_CLASS_DEBUG
                   std::cerr << "property attribute: " << aname << " = "
                             << attribute_value_to_string (attr_p, avalue)
                             << std::endl;
@@ -1205,7 +1263,7 @@ cdef_class::make_meta_class (interpreter& interp,
 
                   prop.doc_string (prop_p->doc_string ());
 
-#if DEBUG_TRACE
+#if OCTAVE_CDEF_CLASS_DEBUG
                   std::cerr << "property: " << prop_p->ident ()->name ()
                             << std::endl;
 #endif
@@ -1215,7 +1273,7 @@ cdef_class::make_meta_class (interpreter& interp,
                     {
                       octave_value pvalue = expr->evaluate (tw);
 
-#if DEBUG_TRACE
+#if OCTAVE_CDEF_CLASS_DEBUG
                       std::cerr << "property default: "
                                 << attribute_value_to_string (prop_p, pvalue)
                                 << std::endl;
