@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1993-2020 The Octave Project Developers
+// Copyright (C) 1993-2026 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -33,29 +33,29 @@
 #include "DASSL.h"
 #include "dMatrix.h"
 #include "f77-fcn.h"
-#include "lo-error.h"
+#include "oct-error.h"
 #include "quit.h"
 
-typedef F77_INT (*dassl_fcn_ptr) (const double&, const double*,
-                                  const double*, double*, F77_INT&,
-                                  double*, F77_INT*);
+typedef F77_INT (*dassl_fcn_ptr) (const double&, const double *,
+                                  const double *, double *, F77_INT&,
+                                  double *, F77_INT *);
 
-typedef F77_INT (*dassl_jac_ptr) (const double&, const double*,
-                                  const double*, double*, const double&,
-                                  double*, F77_INT*);
+typedef F77_INT (*dassl_jac_ptr) (const double&, const double *,
+                                  const double *, double *, const double&,
+                                  double *, F77_INT *);
 
 extern "C"
 {
   F77_RET_T
   F77_FUNC (ddassl, DDASSL) (dassl_fcn_ptr, const F77_INT&, F77_DBLE&,
-                             F77_DBLE*, F77_DBLE*, F77_DBLE&, const F77_INT*,
-                             const F77_DBLE*, const F77_DBLE*, F77_INT&,
-                             F77_DBLE*, const F77_INT&, F77_INT*,
-                             const F77_INT&, const F77_DBLE*, const F77_INT*,
+                             F77_DBLE *, F77_DBLE *, F77_DBLE&, const F77_INT *,
+                             const F77_DBLE *, const F77_DBLE *, F77_INT&,
+                             F77_DBLE *, const F77_INT&, F77_INT *,
+                             const F77_INT&, const F77_DBLE *, const F77_INT *,
                              dassl_jac_ptr);
 }
 
-static DAEFunc::DAERHSFunc user_fun;
+static DAEFunc::DAERHSFunc user_fcn;
 static DAEFunc::DAEJacFunc user_jac;
 
 static F77_INT nn;
@@ -78,7 +78,7 @@ ddassl_f (const double& time, const double *state, const double *deriv,
 
   octave_idx_type tmp_ires = ires;
 
-  tmp_delta = user_fun (tmp_state, tmp_deriv, time, tmp_ires);
+  tmp_delta = user_fcn (tmp_state, tmp_deriv, time, tmp_ires);
 
   ires = octave::to_f77_int (tmp_ires);
 
@@ -125,56 +125,57 @@ DASSL::do_integrate (double tout)
 {
   ColumnVector retval;
 
-  if (! initialized || restart || DAEFunc::reset || DASSL_options::reset)
+  if (! m_initialized || m_restart || DAEFunc::m_reset
+      || DASSL_options::m_reset)
     {
-      integration_error = false;
+      m_integration_error = false;
 
-      initialized = true;
+      m_initialized = true;
 
-      info.resize (dim_vector (15, 1));
+      m_info.resize (dim_vector (15, 1));
 
       for (F77_INT i = 0; i < 15; i++)
-        info(i) = 0;
+        m_info(i) = 0;
 
       F77_INT n = octave::to_f77_int (size ());
 
-      liw = 21 + n;
-      lrw = 40 + 9*n + n*n;
+      m_liw = 21 + n;
+      m_lrw = 40 + 9*n + n*n;
 
       nn = n;
 
-      iwork.resize (dim_vector (liw, 1));
-      rwork.resize (dim_vector (lrw, 1));
+      m_iwork.resize (dim_vector (m_liw, 1));
+      m_rwork.resize (dim_vector (m_lrw, 1));
 
-      info(0) = 0;
+      m_info(0) = 0;
 
-      if (stop_time_set)
+      if (m_stop_time_set)
         {
-          rwork(0) = stop_time;
-          info(3) = 1;
+          m_rwork(0) = m_stop_time;
+          m_info(3) = 1;
         }
       else
-        info(3) = 0;
+        m_info(3) = 0;
 
-      restart = false;
+      m_restart = false;
 
       // DAEFunc
 
-      user_fun = DAEFunc::function ();
+      user_fcn = DAEFunc::function ();
       user_jac = DAEFunc::jacobian_function ();
 
-      if (user_fun)
+      if (user_fcn)
         {
           octave_idx_type ires = 0;
 
-          ColumnVector res = (*user_fun) (x, xdot, t, ires);
+          ColumnVector res = (*user_fcn) (m_x, m_xdot, m_t, ires);
 
-          if (res.numel () != x.numel ())
+          if (res.numel () != m_x.numel ())
             {
               (*current_liboctave_error_handler)
                 ("dassl: inconsistent sizes for state and residual vectors");
 
-              integration_error = true;
+              m_integration_error = true;
               return retval;
             }
         }
@@ -183,116 +184,117 @@ DASSL::do_integrate (double tout)
           (*current_liboctave_error_handler)
             ("dassl: no user supplied RHS subroutine!");
 
-          integration_error = true;
+          m_integration_error = true;
           return retval;
         }
 
-      info(4) = (user_jac ? 1 : 0);
+      m_info(4) = (user_jac ? 1 : 0);
 
-      DAEFunc::reset = false;
+      DAEFunc::m_reset = false;
 
       // DASSL_options
 
       double hmax = maximum_step_size ();
       if (hmax >= 0.0)
         {
-          rwork(1) = hmax;
-          info(6) = 1;
+          m_rwork(1) = hmax;
+          m_info(6) = 1;
         }
       else
-        info(6) = 0;
+        m_info(6) = 0;
 
       double h0 = initial_step_size ();
       if (h0 >= 0.0)
         {
-          rwork(2) = h0;
-          info(7) = 1;
+          m_rwork(2) = h0;
+          m_info(7) = 1;
         }
       else
-        info(7) = 0;
+        m_info(7) = 0;
 
       F77_INT sl = octave::to_f77_int (step_limit ());
 
       if (sl >= 0)
         {
-          info(11) = 1;
-          iwork(20) = sl;
+          m_info(11) = 1;
+          m_iwork(20) = sl;
         }
       else
-        info(11) = 0;
+        m_info(11) = 0;
 
       F77_INT maxord = octave::to_f77_int (maximum_order ());
       if (maxord >= 0)
         {
           if (maxord > 0 && maxord < 6)
             {
-              info(8) = 1;
-              iwork(2) = maxord;
+              m_info(8) = 1;
+              m_iwork(2) = maxord;
             }
           else
             {
               (*current_liboctave_error_handler)
-                ("dassl: invalid value for maximum order: %d", maxord);
-              integration_error = true;
+                ("dassl: invalid value for maximum order: %"
+                 OCTAVE_F77_INT_TYPE_FORMAT, maxord);
+              m_integration_error = true;
               return retval;
             }
         }
 
       F77_INT enc = octave::to_f77_int (enforce_nonnegativity_constraints ());
-      info(9) = (enc ? 1 : 0);
+      m_info(9) = (enc ? 1 : 0);
 
       F77_INT ccic = octave::to_f77_int (compute_consistent_initial_condition ());
-      info(10) = (ccic ? 1 : 0);
+      m_info(10) = (ccic ? 1 : 0);
 
-      abs_tol = absolute_tolerance ();
-      rel_tol = relative_tolerance ();
+      m_abs_tol = absolute_tolerance ();
+      m_rel_tol = relative_tolerance ();
 
-      F77_INT abs_tol_len = octave::to_f77_int (abs_tol.numel ());
-      F77_INT rel_tol_len = octave::to_f77_int (rel_tol.numel ());
+      F77_INT abs_tol_len = octave::to_f77_int (m_abs_tol.numel ());
+      F77_INT rel_tol_len = octave::to_f77_int (m_rel_tol.numel ());
 
       if (abs_tol_len == 1 && rel_tol_len == 1)
         {
-          info(1) = 0;
+          m_info(1) = 0;
         }
       else if (abs_tol_len == n && rel_tol_len == n)
         {
-          info(1) = 1;
+          m_info(1) = 1;
         }
       else
         {
           (*current_liboctave_error_handler)
             ("dassl: inconsistent sizes for tolerance arrays");
 
-          integration_error = true;
+          m_integration_error = true;
           return retval;
         }
 
-      DASSL_options::reset = false;
+      DASSL_options::m_reset = false;
     }
 
-  double *px = x.fortran_vec ();
-  double *pxdot = xdot.fortran_vec ();
+  double *px = m_x.rwdata ();
+  double *pxdot = m_xdot.rwdata ();
 
-  F77_INT *pinfo = info.fortran_vec ();
+  F77_INT *pinfo = m_info.rwdata ();
 
-  double *prel_tol = rel_tol.fortran_vec ();
-  double *pabs_tol = abs_tol.fortran_vec ();
+  double *prel_tol = m_rel_tol.rwdata ();
+  double *pabs_tol = m_abs_tol.rwdata ();
 
-  double *prwork = rwork.fortran_vec ();
-  F77_INT *piwork = iwork.fortran_vec ();
+  double *prwork = m_rwork.rwdata ();
+  F77_INT *piwork = m_iwork.rwdata ();
 
   double *dummy = nullptr;
   F77_INT *idummy = nullptr;
 
-  F77_INT tmp_istate = octave::to_f77_int (istate);
+  F77_INT tmp_istate = octave::to_f77_int (m_istate);
 
-  F77_XFCN (ddassl, DDASSL, (ddassl_f, nn, t, px, pxdot, tout, pinfo,
-                             prel_tol, pabs_tol, tmp_istate, prwork, lrw,
-                             piwork, liw, dummy, idummy, ddassl_j));
+  F77_XFCN (ddassl, DDASSL, (ddassl_f, nn, m_t, px, pxdot, tout, pinfo,
+                             prel_tol, pabs_tol, tmp_istate, prwork, m_lrw,
+                             piwork, m_liw, dummy, idummy, ddassl_j));
 
-  istate = tmp_istate;
+  m_istate = tmp_istate;
 
-  switch (istate)
+  switch (m_istate)
     {
     case 1: // A step was successfully taken in intermediate-output
             // mode.  The code has not yet reached TOUT.
@@ -301,8 +303,8 @@ DASSL::do_integrate (double tout)
     case 3: // The integration to TOUT was successfully completed
             // (T=TOUT) by stepping past TOUT.  Y(*) is obtained by
             // interpolation.  YPRIME(*) is obtained by interpolation.
-      retval = x;
-      t = tout;
+      retval = m_x;
+      m_t = tout;
       break;
 
     case -1: // A large amount of work has been expended.  (~500 steps).
@@ -327,14 +329,14 @@ DASSL::do_integrate (double tout)
               // recover.  A message is printed explaining the trouble
               // and control is returned to the calling program.  For
               // example, this occurs when invalid input is detected.
-      integration_error = true;
+      m_integration_error = true;
       break;
 
     default:
-      integration_error = true;
+      m_integration_error = true;
       (*current_liboctave_error_handler)
         ("unrecognized value of istate (= %" OCTAVE_IDX_TYPE_FORMAT ") "
-         "returned from ddassl", istate);
+         "returned from ddassl", m_istate);
       break;
     }
 
@@ -363,21 +365,21 @@ DASSL::integrate (const ColumnVector& tout, Matrix& xdot_out)
 
       for (F77_INT i = 0; i < n; i++)
         {
-          retval.elem (0, i) = x.elem (i);
-          xdot_out.elem (0, i) = xdot.elem (i);
+          retval.elem (0, i) = m_x.elem (i);
+          xdot_out.elem (0, i) = m_xdot.elem (i);
         }
 
       for (octave_idx_type j = 1; j < n_out; j++)
         {
           ColumnVector x_next = do_integrate (tout.elem (j));
 
-          if (integration_error)
+          if (m_integration_error)
             return retval;
 
           for (F77_INT i = 0; i < n; i++)
             {
               retval.elem (j, i) = x_next.elem (i);
-              xdot_out.elem (j, i) = xdot.elem (i);
+              xdot_out.elem (j, i) = m_xdot.elem (i);
             }
         }
     }
@@ -408,8 +410,8 @@ DASSL::integrate (const ColumnVector& tout, Matrix& xdot_out,
 
       for (F77_INT i = 0; i < n; i++)
         {
-          retval.elem (0, i) = x.elem (i);
-          xdot_out.elem (0, i) = xdot.elem (i);
+          retval.elem (0, i) = m_x.elem (i);
+          xdot_out.elem (0, i) = m_xdot.elem (i);
         }
 
       octave_idx_type n_crit = tcrit.numel ();
@@ -468,7 +470,7 @@ DASSL::integrate (const ColumnVector& tout, Matrix& xdot_out,
 
               ColumnVector x_next = do_integrate (t_out);
 
-              if (integration_error)
+              if (m_integration_error)
                 return retval;
 
               if (save_output)
@@ -476,7 +478,7 @@ DASSL::integrate (const ColumnVector& tout, Matrix& xdot_out,
                   for (F77_INT i = 0; i < n; i++)
                     {
                       retval.elem (i_out-1, i) = x_next.elem (i);
-                      xdot_out.elem (i_out-1, i) = xdot.elem (i);
+                      xdot_out.elem (i_out-1, i) = m_xdot.elem (i);
                     }
                 }
 
@@ -488,7 +490,7 @@ DASSL::integrate (const ColumnVector& tout, Matrix& xdot_out,
         {
           retval = integrate (tout, xdot_out);
 
-          if (integration_error)
+          if (m_integration_error)
             return retval;
         }
     }
@@ -497,15 +499,15 @@ DASSL::integrate (const ColumnVector& tout, Matrix& xdot_out,
 }
 
 std::string
-DASSL::error_message (void) const
+DASSL::error_message () const
 {
   std::string retval;
 
   std::ostringstream buf;
-  buf << t;
+  buf << m_t;
   std::string t_curr = buf.str ();
 
-  switch (istate)
+  switch (m_istate)
     {
     case 1:
       retval = "a step was successfully taken in intermediate-output mode.";
