@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2001-2023 The Octave Project Developers
+// Copyright (C) 2001-2026 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -32,8 +32,8 @@
 
 #include "file-info.h"
 #include "file-stat.h"
-#include "lo-error.h"
-#include "lo-sysdep.h"
+#include "oct-error.h"
+#include "oct-sysdep.h"
 
 OCTAVE_BEGIN_NAMESPACE(octave)
 
@@ -72,7 +72,8 @@ file_info::get_lines (std::size_t line, std::size_t num_lines) const
 
 // Read entire file called fname and return the contents as a string
 
-std::string file_info::snarf_file (const std::string& fname)
+std::string
+file_info::snarf_file (const std::string& fname)
 {
   std::string retval;
 
@@ -103,7 +104,8 @@ std::string file_info::snarf_file (const std::string& fname)
   return retval;
 }
 
-std::vector<std::size_t> file_info::get_line_offsets (const std::string& buf)
+std::vector<std::size_t>
+file_info::get_line_offsets (const std::string& buf)
 {
   std::deque<std::size_t> tmp_offsets;
 
