@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2017-2024 The Octave Project Developers
+## Copyright (C) 2017-2026 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -44,35 +44,42 @@
 ## @var{mad} = median (abs (@var{x} - median (@var{x})))
 ## @end example
 ##
-## If @var{x} is a vector, compute @code{mad} for each element in @var{x}.  If
-## @var{x} is an array the calculation is performed over the first
-## non-singleton dimension.
-##
 ## @code{mad} excludes NaN values from calculation similar to using the
-## @code{omitnan} option in @code{var}, @code{mean}, and @code{median}.
+## @code{omitnan} option in @code{mean} and @code{median}.
 ##
-## The optional argument @var{opt} determines whether mean or median absolute
-## deviation is calculated.  The default is 0 which corresponds to mean
-## absolute deviation; a value of 1 corresponds to median absolute deviation.
-## Passing an empty input [] defaults to mean absolute deviation
-## (@var{opt} = 0).
+## If @var{x} is a vector, then @code{mad (@var{x})} returns the mean absolute
+## deviation of the elements in @var{x}.
 ##
-## The optional argument @var{dim} forces @code{mad} to operate along the
-## specified dimension.  Specifying any singleton dimension in @var{x},
-## including any dimension exceeding @code{ndims (@var{x})}, will result in
-## an output of 0.
+## If @var{x} is a matrix, then @code{mad (@var{x})} returns a row vector with
+## each element containing the mean absolute deviation of the corresponding
+## column in @var{x}.
+##
+## If @var{x} is an array, then @code{mad (@var{x})} computes the mean absolute
+## deviation along the first non-singleton dimension of @var{x}.
+##
+## The optional argument @var{opt} specifies whether mean or median absolute
+## deviation is calculated.  The default is @code{0} which corresponds to mean
+## absolute deviation; a value of @code{1} corresponds to median absolute
+## deviation.  Passing an empty input @code{[]} defaults to mean absolute
+## deviation.
+##
+## The optional input @var{dim} specifies the dimension to operate on and must
+## be a positive integer.  Specifying any singleton dimension of @var{x},
+## including any dimension exceeding @code{ndims (@var{x})}, will return
+## @code{zeros (size (@var{x}))}.
 ##
 ## Specifying the dimension as @var{vecdim}, a vector of non-repeating
 ## dimensions, will return the @code{mad} over the array slice defined by
 ## @var{vecdim}.  If @var{vecdim} indexes all dimensions of @var{x}, then it is
-## equivalent to the option @qcode{"all"}.  Any dimension included in
-## @var{vecdim} greater than @code{ndims (@var{x})} is ignored.
+## equivalent to the option @qcode{"all"}.  Any dimension in @var{vecdim}
+## greater than @code{ndims (@var{x})} is ignored.
 ##
-## Specifying the dimension as @qcode{"all"} will force @code{mad} to operate
+## Specifying the dimension as @qcode{"all"} will cause @code{mad} to operate
 ## on all elements of @var{x}, and is equivalent to @code{mad (@var{x}(:))}.
 ##
-## As a measure of dispersion, @code{mad} is less affected by outliers than
-## @code{std}.
+## Usage Note: As a measure of dispersion, @code{mad} is less affected by
+## outliers than @code{std}.
+##
 ## @seealso{bounds, range, iqr, std, mean, median}
 ## @end deftypefn
 
@@ -83,7 +90,7 @@ function m = mad (x, opt = 0, dim)
   endif
 
   if (! (isnumeric (x) || islogical (x)))
-    error ("mad: X must be a numeric vector or matrix");
+    error ("mad: X must be a numeric or logical array");
   endif
 
   if (isempty (opt))
@@ -236,5 +243,5 @@ endfunction
 
 ## Test input validation
 %!error <Invalid call> mad ()
-%!error <X must be a numeric> mad (['A'; 'B'])
+%!error <X must be a numeric or logical> mad (['A'; 'B'])
 %!error <OPT must be 0 or 1> mad (1, 2)
